import { Observable } from 'rxjs';
import { MediaTypes } from '../types';
import { Conference as Room } from '../wac-proxy/stacks/Janus/Conference';
import { ManagedStream } from './ManagedStream';
export declare enum BackgroundEffect {
    NONE = 0,
    BLUR = 1
}
/**
 * Provides access to methods for managing actions related to local media. Instances of this class
 * are obtained calling {@link Conference#localMediaHandler}
 */
export declare class LocalMediaHandler {
    /** The list of available audio input devices */
    readonly audioInputDevices$: Observable<MediaDeviceInfo[]>;
    /** The list of available video input devices */
    readonly audioOutputDevices$: Observable<MediaDeviceInfo[]>;
    /** The list of available audio output devices */
    readonly videoInputDevices$: Observable<MediaDeviceInfo[]>;
    /** The MediaDeviceInfo of the active audio device */
    readonly activeAudioInputDevice$: Observable<MediaDeviceInfo | undefined>;
    /** The MediaDeviceInfo of the active video device */
    readonly activeVideoInputDevice$: Observable<MediaDeviceInfo | undefined>;
    /** The media types configured for the call */
    readonly mediaTypes$: Observable<Readonly<MediaTypes>>;
    /** The media constraints configured for the call */
    readonly mediaConstraints$: Observable<Readonly<MediaStreamConstraints>>;
    /** The local video stream */
    readonly videoStream$: Observable<ManagedStream | undefined>;
    /** The local audio stream */
    readonly audioOnlyStream$: Observable<ManagedStream | undefined>;
    /** Indicates if video can be enabled or disabled */
    readonly canToggleVideo$: Observable<boolean>;
    /** Indicates if it is possible to change to a different camera */
    readonly canToggleCamera$: Observable<boolean>;
    /** Indicates if local audio is muted */
    readonly isAudioMuted$: Observable<boolean>;
    /** Indicates if push to talk is active */
    readonly isPushToTalkActive$: Observable<boolean>;
    /** Indicates if local video is muted */
    readonly isVideoMuted$: Observable<boolean>;
    private subscription;
    private room;
    private mediaTypesSubject;
    private mediaConstraintsSubject;
    private videoStreamSubject;
    private audioOnlyStreamSubject;
    private isAudioMutedSubject;
    private isVideoMutedSubject;
    private isPushToTalkActiveSubject;
    private beforeShareScreenVideo;
    private devices$;
    private activeAudioInputDevice;
    private activeVideoInputDevice;
    private forceRefreshDevices;
    /** @ignore */
    constructor(mediaConstraints: Readonly<MediaStreamConstraints>, room: Room);
    uninit(): void;
    /**
     * Return the media types configured for the call
     */
    get mediaTypes(): Readonly<MediaTypes>;
    /**
     * Return the media constraints configured for the call
     */
    get mediaConstraints(): Readonly<MediaStreamConstraints>;
    /**
     * Obtains current enabled media stream constraints.
     * This is a combination of the media stream constraints configured
     * for the call and the current media types.
     */
    getCurrentMediaConstraints({ mediaTypes, mediaConstraints, }?: {
        mediaTypes?: Readonly<MediaTypes> | undefined;
        mediaConstraints?: Readonly<MediaStreamConstraints> | undefined;
    }): Readonly<MediaStreamConstraints>;
    /**
     * Returns the local video stream
     */
    get videoStream(): ManagedStream | undefined;
    /**
     * Returns the local audio stream
     */
    get audioOnlyStream(): ManagedStream | undefined;
    /**
     * Indicates if local audio is muted
     */
    get isAudioMuted(): boolean;
    /**
     * Indicates if local video is muted
     */
    get isVideoMuted(): boolean;
    /**
     * Update the enabled local media. This feature is only available
     * when the call has already been connected if "media-update" capability is present.
     * @param mediaTypes The requested media
     *
     * @example <caption>Disable video</caption>
     * await call.setMediaTypes({audio: true, video: false, screen: false});
     * console.log("media updated");
     */
    setMediaTypes(mediaTypes: Readonly<MediaTypes>): Promise<void>;
    /**
     * Update constraints of local media. This feature is only available when the call
     * has already been connected if "media-update" capability is present.
     * @param mediaConstraints The requested media constraints
     *
     * @example <caption>Change video resolution</caption>
     * const audio = true;
     * const video = {
     *   height: 256,
     *   width: 256,
     * };
     * await call.setMediaConstraints({audio, video});
     * console.log("media updated");
     */
    setMediaConstraints(mediaConstraints: Readonly<MediaStreamConstraints>): Promise<void>;
    /** @ignore */
    setVideoStream(stream?: MediaStream): void;
    /** @ignore */
    setAudioOnlyStream(stream?: MediaStream): void;
    /**
     * Mutes or unmutes the audio. If no parameter is specified it toggles current value.
     * @param mute If specified forces audio to be mute or unmute
     */
    muteAudio(mute?: boolean): void;
    /**
     * Turns on the microphone until stopPushToTalk method is called. Does nothing if microphone is not muted
     */
    startPushToTalk(): void;
    /**
     * Turns off the microphone again. Does nothing if startPushToTalk was not called before
     */
    stopPushToTalk(): void;
    /**
     * Mutes or unmutes the video. If no parameter is specified it toggles current value.
     *
     * Note that this method just turns the emitted video black and implies no media renegotiation.
     * Therefore, a video track will continue to be streamed. If you are instead looking for a method
     * to stop sending video altogether check {@link LocalMediaHandler.toggleVideo}.
     * @param mute When specified forces video to be mute or unmute
     */
    muteVideo(mute?: boolean): void;
    /**
     * Enables or disables the video. If no parameter is specified it toggles current value.
     *
     * Note that this method will imply a media renegotation because the video track will be
     * added or removed from the RTCPeerConnection. As a consequence, remote participants
     * will receive a change in their remote participants streams.
     * @param video If specified forces video to be enabled or not
     */
    toggleVideo(video?: boolean): Promise<void>;
    /**
     * Shares the screen. This feature is only available if "screen-sharing" capability is present.
     * @param screen send screen if true, camera if false. If not specified it toggles from the last state.
     */
    toggleScreen(screen?: boolean): Promise<void>;
    get backgroundEffect(): BackgroundEffect;
    set backgroundEffect(backgroundEffect: BackgroundEffect);
    /**
     * Updates media types adding video when screen is false or adds an internal mark to know video must be
     * enabled when screen sharing ends.
     */
    addVideo(): Promise<void>;
    /**
     * Updates the audio input device in used to the specified one
     * @param audioInputDevice If no value is specified the default one is selected
     */
    setActiveAudioInputDevice(audioInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Updates the video input device in used to the specified one
     * @param videoInputDevice If no value is specified the default one is selected
     */
    setActiveVideoInputDevice(videoInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Changes the local video stream to the next available camera.
     */
    toggleCamera(): Promise<void>;
    /**
     * Force the update of the devices list
     */
    forceUpdateDevices(): Promise<void>;
    private getActiveVideoInputDeviceFromLocalStreams;
    private getNextVideoInputDevice;
}
