import { JanusRoom } from '@quobis/wrapper-stack';
import { ConferenceMediaStream } from '@quobis/wrapper-stack/lib/conference-media/ConferenceMediaStream';
import { Observable } from 'rxjs';
import { Dtmf, MediaTypes } from '../../../types';
import { MediaManager } from '../MediaManager';
import { Session } from './Session';
import { AttendedTransferResponseData } from './signaling/CallTransferAPI';
export interface MuteChangeEvent {
    userId: string;
    muted: boolean;
}
export interface StreamEvent {
    userId: string;
    stream: MediaStream;
    mediaTypes: MediaTypes;
}
export interface CallTransferEvent {
    to: string;
    callTransferId: string;
    roomId: string;
    mediaTypes: MediaTypes;
}
export interface ParticipantEvent {
    userId: string;
    status: 'GONE' | 'HOLD' | 'IN_CALL';
}
export interface SpeakerChangedEvent {
    userId: string;
    isTalking: boolean;
}
type JanusRoom = any;
interface InviteFromDetails {
    contactName: string;
    displayName: string;
    username: string;
}
interface Invite {
    id: string;
    from: string;
    mediatypes: MediaTypes;
    context: Record<string, string> & {
        contextInfo?: Record<string, string>;
    };
    fromDetails: InviteFromDetails;
}
interface Dependencies {
    session?: Session;
    WebSocket?: typeof WebSocket;
    room?: JanusRoom;
}
export declare class Conference {
    private dependencies;
    callTransfer$: Observable<CallTransferEvent>;
    destroyed$: Observable<void>;
    localStreamAdded$: Observable<StreamEvent>;
    localStreamRemoved$: Observable<StreamEvent>;
    muteChange$: Observable<MuteChangeEvent>;
    muteRequest$: Observable<boolean>;
    participant$: Observable<ParticipantEvent>;
    remoteStreamAdded$: Observable<StreamEvent>;
    remoteStreamRemoved$: Observable<StreamEvent>;
    speakerChange$: Observable<SpeakerChangedEvent>;
    mediaManager: MediaManager;
    private mediaUpdateLock;
    /**
     * Server client
     */
    private _session;
    /**
     * Janus client
     */
    private _room;
    /**
     * Room identifier
     */
    private _id;
    /**
     * Invitation when user doesn't joined the conference.
     */
    private _invite;
    /**
     * User identifiers that participate on a conference.
     */
    private _participants;
    /**
     * Indicates if conference is being recorded
     */
    private _record;
    /**
     * Conference server
     */
    private _server;
    /**
     * Conference access token
     */
    private _token;
    /**
     * Conference ice servers
     */
    private _ice;
    /**
     * Contains a list of pending invitations (still not accepted/rejected
     * by remote peer) transaction identifiers. Used to cancel a previous invitation
     * and determine if an user has been invited.
     */
    private _pendingInvites;
    /**
     * True if leave method was called
     */
    private _left;
    private parallelSipExtension;
    private sipUri;
    private _uninitializingRoom;
    private subscription;
    private callTransferSubject;
    private destroyedSubject;
    private muteChangeSubject;
    private muteRequestSubject;
    private localStreamAddedSubject;
    private localStreamRemovedSubject;
    private participantSubject;
    private remoteStreamAddedSubject;
    private remoteStreamRemovedSubject;
    private speakerChangeSubject;
    constructor(dependencies?: Dependencies);
    /**
     * Conference identifier
     */
    get id(): string;
    /**
     * Indicate if invited
     */
    get invited(): boolean;
    /**
     * Returns an object with the invitation (with the properties "id" an "from")
     * Needed to know who is inviting us in anonymous rooms
     */
    get invite(): Invite | null;
    /**
     * Indicate if joined
     */
    get joined(): boolean;
    /**
     * Server session.
     */
    set session(session: Session | null);
    /**
     * Conference participants, expressed as a list of current user identifiers
     */
    get participants(): string[];
    /**
     * Current local streams.
     */
    get localStreams(): ConferenceMediaStream[];
    /**
     * Current remote streams.
     */
    get remoteStreams(): ConferenceMediaStream[];
    /**
     * Current conference streams.
     */
    get streams(): ConferenceMediaStream[];
    /**
     * Local hold
     * Stop publishing and subscribing to the media in the conference
     */
    hold(): Promise<void>;
    /**
     * Stop local hold
     * Republishes all previously published media, subscribes to previously subscribed
     * media and notifies new status to other participants.
     */
    unhold(): Promise<void>;
    /**
     * Check if conference is on hold state.
     */
    get isOnHold(): boolean;
    /**
     * Suspend conference:
     *  - cancel any pending invitation sent.
     *  - decline invitation if we was invited to this conference.
     */
    suspend(): Promise<void>;
    /**
     * Resume conference
     */
    resume(): Promise<void>;
    /**
     * Join this conference and start sending local media defined by mediatype parameter.
     * @param mediatypes local media used after joining the conference.
     */
    join(mediatypes: MediaStreamConstraints): Promise<void>;
    /**
     * Add participant to this conference.
     * @throws {Error} if participant is already present on conference or a pending
     * invitation exists.
     * @param participant user name to add.
     * @param mediatypes the mediatypes requested to the new participant.
     * @param requestId the ID of the request that generated this invitation.
     * @param context arbitrary context that can be sent to invites
     * @return resolved with a boolean value that indicates if remote accepts the invitation.
     */
    inviteParticipant(participant: string, mediatypes: MediaTypes, requestId?: string, context?: Record<string, string>): Promise<{
        code: number;
        whoAccepted?: string;
    }>;
    /**
     * Cancel an invite
     * @param participant user name to decline.
     */
    cancelInvitation(participant: string): void;
    cancelPendingInvite(participant: string): void;
    /**
     * Removes a participant from this conference.
     * @param participant user name to remove.
     * @return resolved when remote user leaves conference.
     */
    expelParticipant(participant: string): Promise<void>;
    /**
     * Leaves this conference or rejects a previous invitation.
     * @param errorCode the rejection cause when an invitation is received
     * and the conference has not been joined.
     * @throws {Error} when already joined or a previous invitation was not received.
     * @return resolved on success with self reference.
     */
    leave(errorCode?: number): Promise<Conference>;
    /**
     * Deinitialize Janus client after leaving a conference.
     * @return {Promise} resolved on success
     */
    private uninitRoom;
    private uninitRoomIfExists;
    /**
     * Update local media types.
     * @param mediatypes required mediatypes.
     */
    update(mediatypes: MediaStreamConstraints | {
        screen: boolean;
    }): Promise<void>;
    /**
     * True if conference is being recorded
     */
    get recording(): boolean;
    /**
     * Starts recording this conference
     */
    startRecording(): Promise<Conference>;
    /**
     * Stops conference recording
     */
    stopRecording(): Promise<Conference>;
    /**
     * Create an unattended call transfer towards a user in the system
     * @param participant user name to call.
     * @param mediatypes the mediatypes requested to the new participant.
     */
    unattendedCallTransfer(participant: string, mediatypes: MediaTypes): Promise<void>;
    /**
     * Accept inviting to other participant to make an unattended call transfer
     * @param {string} callTransferID identifier of a call transfer
     */
    acceptCallTransfer(callTransferID: string): Promise<void>;
    /**
     * Create an attended call transfer towards a user in the system
     * @param target user that will be inserted in conference.
     * @param transferee user who will stay in the transferred conference
     */
    createAttendedCallTransfer(target: string, transferee: string): Promise<AttendedTransferResponseData>;
    /**
     * Executes the in progress attended call transfer.
     * @param target who must be inserted in conference.
     */
    executeAttendedTransfer(target: string, roomId: string): Promise<AttendedTransferResponseData>;
    /**
     * Cancels the in progress attended call transfer.
     * @param target who must be inserted in conference.
     */
    cancelAttendedTransfer(target: string): Promise<AttendedTransferResponseData>;
    sendDtmf(value: Dtmf): Promise<unknown>;
    getParticipants(): unknown;
    muteRequest(to: string, muted: boolean): Promise<void>;
    mute(muted: boolean): Promise<void>;
    private createJanusRoom;
    /**
     * Initialize Janus client after joining a conference.
     */
    private initRoom;
    private removeRoomListeners;
    /**
     * Updates instance properties with data returned by a signaling server
     * @param {object} data server data
     */
    updateWithServerData(data: any): Conference;
    /**
     * Callback called when a destroyed room event is received
     */
    private onRoomDestroyed;
    /**
     * Callback called when a room update event is received
     */
    private onRoomUpdated;
    /**
     * Callback called when an invitation is canceled
     */
    private onInviteCancel;
    /**
     * Callback called when a ConferenceMediaStream is added
     */
    private onStreamAdded;
    /**
     * Callback called when a ConferenceMediaStream is removed
     */
    private onStreamRemoved;
    /**
     * Callback called when an invitation is canceled
     */
    private onTransferringCallToPeer;
    /**
     * Callback called when a new participant joins the room
     */
    private onParticipantAdded;
    /**
     * Callback called when a participant leaves the room
     */
    private onParticipantRemoved;
    /**
     * Callback called when a remote participant does a hold
     */
    private onParticipantHold;
    /**
     * Callback called when a remote participant stops a hold
     */
    private onParticipantUnhold;
    /**
     * Callback called when change the participants who are speaking
     */
    private onSpeakerChanged;
}
export {};
