import { Observable } from 'rxjs';
import { MediaTypes } from '../../../types';
import { Conference } from './Conference';
import { Session } from './Session';
interface Dependencies {
    WebSocket?: typeof WebSocket;
}
/**
 * This class implements a Conferences module that provides access
 * to conference management methods.
 *
 * Events
 *  - incomingConference: Fired when an invitation to a conference is received.
 */
export declare class Conferences {
    private dependencies;
    incomingConference$: Observable<[Conference, MediaTypes]>;
    transferredConference$: Observable<[Conference, MediaTypes]>;
    /** Server client */
    private session;
    /** Conference collection, indexed by id */
    private conferences;
    private incomingConferenceSubject;
    private transferredConferenceSubject;
    constructor(dependencies?: Dependencies);
    /**
     * Initialize conferences module.
     * Get any room where user participates from server and create Conference
     * elements with them.
     * It also listens for new rooms notified by server.
     * @param session associated signaling session.
     */
    init(session: Session): Promise<void>;
    /**
     * Deinitialize conferences module.
     * Stops listening for new rooms messages from server.
     */
    uninit(): void;
    /**
     * Suspend conferences:
     *  - cancel any pending invitation request sent.
     *  - update internally any received invitation request to canceled.
     *  - suspend any managed conference.
     */
    suspend(): Promise<void>;
    /**
     * Resume conferences:
     *  - resume any managed conference.
     */
    resume(): Promise<void>;
    /**
     * Get any conference where user is included as participant.
     */
    fetch(): Conference[];
    /**
     * Get an existing conference by conference ID.
     * @param conferenceId conference ID.
     */
    get(conferenceId: string): Conference;
    /**
     * Creates a new conference with given identifier.
     * @param recording indicating whether the conference is going to be recorded or not
     * @return {Promise<Conference>} created conference on success.
     */
    create(recording: boolean): Promise<Conference>;
    /**
     * Retrieves current invitations
     *
     * @return A resolved promise with an array of Conferences if succeeds
     */
    getCurrentInvitations(): Promise<Conference[]>;
    /**
     * Returns a meeting conference
     * @param meetingId
     * @param password
     * @return conference for the meeting
     */
    getMeetingConference(meetingId: string, password?: string): Promise<Conference>;
    /**
     * Returns a quick conference
     * @param quickConferenceId
     * @return conference for the meeting
     */
    getQuickConference(quickConferenceId: string): Promise<Conference>;
    private createNewConference;
    createConferenceForRoom(room: any): Conference;
    /**
     * Add a conference to collection.
     * @param conference conference to add.
     */
    private addConferenceToCollection;
    /**
     * Removes a conference from collection
     * @param id conference identifier
     */
    private removeConferenceFromCollection;
    /**
     * Event listener called when a room update message is received
     * @param {object} data
     */
    private onRoomUpdated;
    /**
     * Event listener called when an invite is received
     * @param {object} data
     */
    private onIncomingInvite;
    private updateWithServerData;
    /**
     * Event listener called when an invite to transferred call is received
     * @param {object} data
     */
    private onTransferringAttendedTransfer;
}
export {};
